GoogleSearch_services.doSpellingSuggestionWrapper

|  | ## Cheshire3 Object Model: Class doSpellingSuggestionWrapper

Module GoogleSearch_services :: Class doSpellingSuggestionWrapper

## Class doSpellingSuggestionWrapper
source code

Object Tree:

          TC.TypeCode --+
                        |
    ZSI.TCcompound.Struct --+
                            |
         doSpellingSuggestion --+
                                |
                               doSpellingSuggestionWrapper

wrapper for rpc:encoded message
Instance Methods

__init__(self, name=None, ns=None)
Inherited from `ZSI.TCcompound.Struct`: `cb`, `parse`, `serialize` Inherited from `ZSI.TC.TypeCode`: `SimpleHREF`, `checkname`, `checktype`, `get_parse_and_errorlist`, `name_match`, `nilled`, `simple_value`

Class Variables

typecode |
Inherited from `ZSI.TC.TypeCode`: `typechecks`

Method Details

### __init__(self, name=None, ns=None) (Constructor) | source code
Overrides: doSpellingSuggestion.__init__

Class Variable Details

    ### typecode Value:
        <GoogleSearch_services.doSpellingSuggestion instance at 0xb766b2cc>